
# pyrockoeost plot Module

* `pyrockoeost.plot.automap` Quickly generate pretty maps using gmtpy's powers.
* `pyrockoeost.plot.beachball` Beachball visualisation for `matplotlib`.
* `pyrockoeost.plot.cake_plot` Plotting velocities models and ray paths.
* `pyrockoeost.plot.hudson` Generate hudson plots with this module.
* `pyrockoeost.plot.response` Plot the station's response's.

## GMTPy

`pyrockoeost.plot.gmtpy` With support for GMT5 and GMT6 pyrockoeost's gmtpy exposes GMT's neat mapping functions to Python 3.
